OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "No contacts in here" : "Ingen kontaktpersoner her",
    "Name" : "Navn",
    "Organization" : "Organisation",
    "Title" : "Titel",
    "Add field ..." : "Tilføj felt...",
    "Add contact" : "Tilføj kontaktpeson.",
    "All contacts" : "Alle kontakter",
    "Not grouped" : "Ikke i gruppe",
    "Postal Code" : "Postnummer",
    "City" : "By",
    "State or province" : "Stat eller provins",
    "Country" : "Land",
    "Address" : "Adresse",
    "{addressbook} shared by {owner}" : "{addressbook} delt af {owner}",
    "Nickname" : "Kaldenavn",
    "Notes" : "Noter",
    "Website" : "Hjemmeside",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Hjemme",
    "Work" : "Arbejde",
    "Other" : "Andet",
    "Groups" : "Grupper",
    "Birthday" : "Fødselsdag",
    "Email" : "E-mail",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hjemme",
    "Fax work" : "Fax arbejde",
    "Pager" : "Personsøger",
    "Voice" : "Telefonsvarer",
    "Settings" : "Indstillinger",
    "Import" : "Importér"
},
"nplurals=2; plural=(n != 1);");
